@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,17 +9,17 @@
 #include "widgets/unitcombobox.h"
 #include <MailCommon/FolderRequester>
 
-#include <KLocalizedString>
-#include <KUrlRequester>
 #include <KLineEdit>
-#include <QSpinBox>
+#include <KLocalizedString>
 #include <KSeparator>
+#include <KUrlRequester>
 #include <QIcon>
+#include <QSpinBox>
 
-#include <QGridLayout>
-#include <QLabel>
 #include <QCheckBox>
 #include <QDialogButtonBox>
+#include <QGridLayout>
+#include <QLabel>
 #include <QPushButton>
 #include <QVBoxLayout>
 
@@ -35,28 +35,28 @@ AddArchiveMailDialog::AddArchiveMailDialog(ArchiveMailInfo *info, QWidget *paren
     setModal(true);
     setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
 
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
 
-    auto *mainLayout = new QGridLayout;
+    auto mainLayout = new QGridLayout;
     mainLayout->setContentsMargins({});
 
     int row = 0;
 
-    QLabel *folderLabel = new QLabel(i18n("&Folder:"), this);
+    auto folderLabel = new QLabel(i18n("&Folder:"), this);
     mainLayout->addWidget(folderLabel, row, 0);
     mFolderRequester = new MailCommon::FolderRequester(this);
     mFolderRequester->setObjectName(QStringLiteral("folder_requester"));
     mFolderRequester->setMustBeReadWrite(false);
     mFolderRequester->setNotAllowToCreateNewFolder(true);
     connect(mFolderRequester, &MailCommon::FolderRequester::folderChanged, this, &AddArchiveMailDialog::slotFolderChanged);
-    if (info) { //Don't autorize to modify folder when we just modify item.
+    if (info) { // Don't autorize to modify folder when we just modify item.
         mFolderRequester->setEnabled(false);
     }
     folderLabel->setBuddy(mFolderRequester);
     mainLayout->addWidget(mFolderRequester, row, 1);
     ++row;
 
-    QLabel *formatLabel = new QLabel(i18n("Format:"), this);
+    auto formatLabel = new QLabel(i18n("Format:"), this);
     formatLabel->setObjectName(QStringLiteral("label_format"));
     mainLayout->addWidget(formatLabel, row, 0);
 
@@ -70,7 +70,7 @@ AddArchiveMailDialog::AddArchiveMailDialog(ArchiveMailInfo *info, QWidget *paren
     mRecursiveCheckBox->setChecked(true);
     ++row;
 
-    QLabel *pathLabel = new QLabel(i18n("Path:"), this);
+    auto pathLabel = new QLabel(i18n("Path:"), this);
     mainLayout->addWidget(pathLabel, row, 0);
     pathLabel->setObjectName(QStringLiteral("path_label"));
     mPath = new KUrlRequester(this);
@@ -80,11 +80,11 @@ AddArchiveMailDialog::AddArchiveMailDialog(ArchiveMailInfo *info, QWidget *paren
     mainLayout->addWidget(mPath);
     ++row;
 
-    QLabel *dateLabel = new QLabel(i18n("Backup each:"), this);
+    auto dateLabel = new QLabel(i18n("Backup each:"), this);
     dateLabel->setObjectName(QStringLiteral("date_label"));
     mainLayout->addWidget(dateLabel, row, 0);
 
-    auto *hlayout = new QHBoxLayout;
+    auto hlayout = new QHBoxLayout;
     mDays = new QSpinBox(this);
     mDays->setMinimum(1);
     mDays->setMaximum(3600);
@@ -96,7 +96,7 @@ AddArchiveMailDialog::AddArchiveMailDialog(ArchiveMailInfo *info, QWidget *paren
     mainLayout->addLayout(hlayout, row, 1);
     ++row;
 
-    QLabel *maxCountlabel = new QLabel(i18n("Maximum number of archive:"), this);
+    auto maxCountlabel = new QLabel(i18n("Maximum number of archive:"), this);
     mainLayout->addWidget(maxCountlabel, row, 0);
     mMaximumArchive = new QSpinBox(this);
     mMaximumArchive->setMinimum(0);
@@ -110,7 +110,7 @@ AddArchiveMailDialog::AddArchiveMailDialog(ArchiveMailInfo *info, QWidget *paren
     mainLayout->setColumnStretch(1, 1);
     mainLayout->addItem(new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Expanding), row, 0);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setDefault(true);
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -129,8 +129,7 @@ AddArchiveMailDialog::AddArchiveMailDialog(ArchiveMailInfo *info, QWidget *paren
     resize(500, minimumSize().height());
 }
 
-AddArchiveMailDialog::~AddArchiveMailDialog()
-= default;
+AddArchiveMailDialog::~AddArchiveMailDialog() = default;
 
 void AddArchiveMailDialog::load(ArchiveMailInfo *info)
 {
@@ -167,7 +166,7 @@ void AddArchiveMailDialog::slotUpdateOkButton()
 
 void AddArchiveMailDialog::slotFolderChanged(const Akonadi::Collection &collection)
 {
-    Q_UNUSED(collection);
+    Q_UNUSED(collection)
     slotUpdateOkButton();
 }
 
