@@ -1,26 +1,27 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "followupreminderinfowidget.h"
+#include "followupreminderagent_debug.h"
 #include "followupreminderinfo.h"
 #include "followupreminderutil.h"
 #include "jobs/followupremindershowmessagejob.h"
-#include "followupreminderagent_debug.h"
 
-#include <QTreeWidget>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSharedConfig>
 #include <QHBoxLayout>
 #include <QHeaderView>
-#include <QLocale>
 #include <QIcon>
+#include <QLocale>
 #include <QMenu>
-#include <KLocalizedString>
-#include <KSharedConfig>
-#include <KMessageBox>
+#include <QTreeWidget>
 
 // #define DEBUG_MESSAGE_ID
-namespace {
+namespace
+{
 inline QString followUpItemPattern()
 {
     return QStringLiteral("FollowupReminderItem \\d+");
@@ -51,20 +52,16 @@ FollowUpReminderInfoWidget::FollowUpReminderInfoWidget(QWidget *parent)
     : QWidget(parent)
 {
     setObjectName(QStringLiteral("FollowUpReminderInfoWidget"));
-    auto *hbox = new QHBoxLayout(this);
+    auto hbox = new QHBoxLayout(this);
     hbox->setContentsMargins({});
     mTreeWidget = new QTreeWidget(this);
     mTreeWidget->setObjectName(QStringLiteral("treewidget"));
     QStringList headers;
-    headers << i18n("To")
-            << i18n("Subject")
-            << i18n("Dead Line")
-            << i18n("Answer")
+    headers << i18n("To") << i18n("Subject") << i18n("Dead Line") << i18n("Answer")
 #ifdef DEBUG_MESSAGE_ID
-        << QStringLiteral("Message Id")
-        << QStringLiteral("Answer Message Id")
+            << QStringLiteral("Message Id") << QStringLiteral("Answer Message Id")
 #endif
-    ;
+        ;
 
     mTreeWidget->setHeaderLabels(headers);
     mTreeWidget->setSortingEnabled(true);
@@ -77,8 +74,7 @@ FollowUpReminderInfoWidget::FollowUpReminderInfoWidget(QWidget *parent)
     hbox->addWidget(mTreeWidget);
 }
 
-FollowUpReminderInfoWidget::~FollowUpReminderInfoWidget()
-= default;
+FollowUpReminderInfoWidget::~FollowUpReminderInfoWidget() = default;
 
 void FollowUpReminderInfoWidget::setInfo(const QList<FollowUpReminder::FollowUpReminderInfo *> &infoList)
 {
@@ -100,7 +96,7 @@ void FollowUpReminderInfoWidget::load()
     for (int i = 0; i < numberOfItem; ++i) {
         KConfigGroup group = config->group(filterGroups.at(i));
 
-        auto *info = new FollowUpReminder::FollowUpReminderInfo(group);
+        auto info = new FollowUpReminder::FollowUpReminderInfo(group);
         if (info->isValid()) {
             createOrUpdateItem(info);
         } else {
@@ -157,7 +153,7 @@ bool FollowUpReminderInfoWidget::save() const
     const int numberOfItem(mTreeWidget->topLevelItemCount());
     int i = 0;
     for (; i < numberOfItem; ++i) {
-        auto *mailItem = static_cast<FollowUpReminderInfoItem *>(mTreeWidget->topLevelItem(i));
+        auto mailItem = static_cast<FollowUpReminderInfoItem *>(mTreeWidget->topLevelItem(i));
         if (mailItem->info()) {
             KConfigGroup group = config->group(FollowUpReminder::FollowUpReminderUtil::followUpReminderPattern().arg(i));
             mailItem->info()->writeConfig(group, i);
@@ -172,7 +168,7 @@ bool FollowUpReminderInfoWidget::save() const
 
 void FollowUpReminderInfoWidget::slotCustomContextMenuRequested(const QPoint &pos)
 {
-    Q_UNUSED(pos);
+    Q_UNUSED(pos)
     const QList<QTreeWidgetItem *> listItems = mTreeWidget->selectedItems();
     const int nbElementSelected = listItems.count();
     if (nbElementSelected > 0) {
@@ -200,7 +196,7 @@ void FollowUpReminderInfoWidget::slotCustomContextMenuRequested(const QPoint &po
 
 void FollowUpReminderInfoWidget::openShowMessage(Akonadi::Item::Id id)
 {
-    auto *job = new FollowUpReminderShowMessageJob(id);
+    auto job = new FollowUpReminderShowMessageJob(id);
     job->start();
 }
 
@@ -209,10 +205,13 @@ void FollowUpReminderInfoWidget::removeItem(const QList<QTreeWidgetItem *> &mail
     if (mailItemLst.isEmpty()) {
         qCDebug(FOLLOWUPREMINDERAGENT_LOG) << "Not item selected";
     } else {
-        if (KMessageBox::Yes == KMessageBox::warningYesNo(this,
-                                                          i18np("Do you want to remove this selected item?", "Do you want to remove these %1 selected items?", mailItemLst.count()), i18n("Delete"))) {
+        if (KMessageBox::Yes
+            == KMessageBox::warningYesNo(
+                this,
+                i18np("Do you want to remove this selected item?", "Do you want to remove these %1 selected items?", mailItemLst.count()),
+                i18n("Delete"))) {
             for (QTreeWidgetItem *item : mailItemLst) {
-                auto *mailItem = static_cast<FollowUpReminderInfoItem *>(item);
+                auto mailItem = static_cast<FollowUpReminderInfoItem *>(item);
                 mListRemoveId << mailItem->info()->uniqueIdentifier();
                 delete mailItem;
             }
