@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,17 +7,17 @@
 #include "followupremindermanager.h"
 #include "followupreminderagent_debug.h"
 #include "followupreminderinfo.h"
-#include "followupreminderutil.h"
 #include "followupremindernoanswerdialog.h"
-#include "jobs/followupreminderjob.h"
+#include "followupreminderutil.h"
 #include "jobs/followupreminderfinishtaskjob.h"
+#include "jobs/followupreminderjob.h"
 
 #include <Akonadi/KMime/SpecialMailCollections>
 
-#include <KConfigGroup>
 #include <KConfig>
-#include <KNotification>
+#include <KConfigGroup>
 #include <KLocalizedString>
+#include <KNotification>
 #include <QRegularExpression>
 using namespace FollowUpReminder;
 
@@ -44,12 +44,12 @@ void FollowUpReminderManager::load(bool forceReloadConfig)
     for (int i = 0; i < numberOfItems; ++i) {
         KConfigGroup group = mConfig->group(itemList.at(i));
 
-        auto *info = new FollowUpReminderInfo(group);
+        auto info = new FollowUpReminderInfo(group);
         if (info->isValid()) {
             if (!info->answerWasReceived()) {
                 mFollowUpReminderInfoList.append(info);
                 if (!mInitialize) {
-                    auto *noAnswerInfo = new FollowUpReminderInfo(*info);
+                    auto noAnswerInfo = new FollowUpReminderInfo(*info);
                     noAnswerList.append(noAnswerInfo);
                 } else {
                     delete info;
@@ -65,7 +65,10 @@ void FollowUpReminderManager::load(bool forceReloadConfig)
         mInitialize = true;
         if (!mNoAnswerDialog.data()) {
             mNoAnswerDialog = new FollowUpReminderNoAnswerDialog;
-            connect(mNoAnswerDialog.data(), &FollowUpReminderNoAnswerDialog::needToReparseConfiguration, this, &FollowUpReminderManager::slotReparseConfiguration);
+            connect(mNoAnswerDialog.data(),
+                    &FollowUpReminderNoAnswerDialog::needToReparseConfiguration,
+                    this,
+                    &FollowUpReminderManager::slotReparseConfiguration);
         }
         mNoAnswerDialog->setInfo(noAnswerList);
         mNoAnswerDialog->wakeUp();
@@ -104,7 +107,7 @@ void FollowUpReminderManager::checkFollowUp(const Akonadi::Item &item, const Ako
         break;
     }
 
-    auto *job = new FollowUpReminderJob(this);
+    auto job = new FollowUpReminderJob(this);
     connect(job, &FollowUpReminderJob::finished, this, &FollowUpReminderManager::slotCheckFollowUpFinished);
     job->setItem(item);
     job->start();
@@ -122,12 +125,12 @@ void FollowUpReminderManager::slotCheckFollowUpFinished(const QString &messageId
             info->setAnswerWasReceived(true);
             answerReceived(info->to());
             if (info->todoId() != -1) {
-                auto *job = new FollowUpReminderFinishTaskJob(info->todoId(), this);
+                auto job = new FollowUpReminderFinishTaskJob(info->todoId(), this);
                 connect(job, &FollowUpReminderFinishTaskJob::finishTaskDone, this, &FollowUpReminderManager::slotFinishTaskDone);
                 connect(job, &FollowUpReminderFinishTaskJob::finishTaskFailed, this, &FollowUpReminderManager::slotFinishTaskFailed);
                 job->start();
             }
-            //Save item
+            // Save item
             FollowUpReminder::FollowUpReminderUtil::writeFollowupReminderInfo(FollowUpReminder::FollowUpReminderUtil::defaultConfig(), info, true);
             break;
         }
@@ -137,13 +140,13 @@ void FollowUpReminderManager::slotCheckFollowUpFinished(const QString &messageId
 void FollowUpReminderManager::slotFinishTaskDone()
 {
     qCDebug(FOLLOWUPREMINDERAGENT_LOG) << " Task Done";
-    //TODO
+    // TODO
 }
 
 void FollowUpReminderManager::slotFinishTaskFailed()
 {
     qCDebug(FOLLOWUPREMINDERAGENT_LOG) << " Task Failed";
-    //TODO
+    // TODO
 }
 
 void FollowUpReminderManager::answerReceived(const QString &from)
