@@ -16,7 +16,8 @@
 
 #include <QDialog>
 
-namespace KTnef {
+namespace KTnef
+{
 class KTNEFMessage;
 }
 using namespace KTnef;
@@ -28,7 +29,7 @@ class MessagePropertyDialog : public QDialog
     Q_OBJECT
 public:
     explicit MessagePropertyDialog(QWidget *parent, KTNEFMessage *msg);
-    ~MessagePropertyDialog();
+    ~MessagePropertyDialog() override;
 
 private:
     void slotSaveProperty();
