@@ -7,17 +7,17 @@
 */
 
 #include "collectionshortcutpage.h"
+#include "foldershortcutactionmanager.h"
 #include "kmkernel.h"
 #include "kmmainwidget.h"
-#include "foldershortcutactionmanager.h"
 
 #include <QLabel>
 #include <QSpacerItem>
 #include <QVBoxLayout>
 
-#include <QHBoxLayout>
-#include <KLocalizedString>
 #include <KKeySequenceWidget>
+#include <KLocalizedString>
+#include <QHBoxLayout>
 
 using namespace MailCommon;
 
@@ -28,24 +28,24 @@ CollectionShortcutPage::CollectionShortcutPage(QWidget *parent)
     setPageTitle(i18nc("@title:tab Shortcut settings for a folder.", "Shortcut"));
 }
 
-CollectionShortcutPage::~CollectionShortcutPage()
-= default;
+CollectionShortcutPage::~CollectionShortcutPage() = default;
 
 void CollectionShortcutPage::init(const Akonadi::Collection &col)
 {
     mCurrentCollection = col;
     mFolder = FolderSettings::forCollection(col, false);
 
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
 
-    QLabel *label = new QLabel(i18n("<qt>To choose a key or a combination "
-                                    "of keys which select the current folder, "
-                                    "click the button below and then press the key(s) "
-                                    "you wish to associate with this folder.</qt>"), this);
+    auto label = new QLabel(i18n("<qt>To choose a key or a combination "
+                                 "of keys which select the current folder, "
+                                 "click the button below and then press the key(s) "
+                                 "you wish to associate with this folder.</qt>"),
+                            this);
     label->setWordWrap(true);
     topLayout->addWidget(label);
 
-    auto *hbHBoxLayout = new QHBoxLayout;
+    auto hbHBoxLayout = new QHBoxLayout;
 
     mKeySeqWidget = new KKeySequenceWidget(this);
     hbHBoxLayout->addWidget(mKeySeqWidget);
@@ -63,8 +63,7 @@ void CollectionShortcutPage::load(const Akonadi::Collection &col)
 {
     init(col);
     if (mFolder) {
-        mKeySeqWidget->setKeySequence(mFolder->shortcut(),
-                                      KKeySequenceWidget::NoValidate);
+        mKeySeqWidget->setKeySequence(mFolder->shortcut(), KKeySequenceWidget::NoValidate);
         mShortcutChanged = false;
     }
 }
