@@ -1,20 +1,9 @@
 /*
   This file is part of KMail, the KDE mail client.
-  Copyright (c) 2004 Till Adam <adam@kde.org>
-  Copyright (c) 2013 Jonathan Marten <jjm@keelhaul.me.uk>
+  SPDX-FileCopyrightText: 2004 Till Adam <adam@kde.org>
+  SPDX-FileCopyrightText: 2013 Jonathan Marten <jjm@keelhaul.me.uk>
 
-  KMail is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  KMail is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #ifndef COLLECTIONSHORTCUTPAGE_H
