@@ -1,44 +1,44 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "configureaccountpage.h"
-#include "dialog/kmknotify.h"
-#include "newmailnotifierinterface.h"
-#include "kmkernel.h"
-#include "settings/kmailsettings.h"
 #include "configagentdelegate.h"
+#include "dialog/kmknotify.h"
+#include "kmkernel.h"
+#include "newmailnotifierinterface.h"
+#include "settings/kmailsettings.h"
 #include "undosend/undosendcombobox.h"
-#include <MessageComposer/MessageComposerSettings>
 #include <MailCommon/AccountConfigOrderDialog>
+#include <MessageComposer/MessageComposerSettings>
 #include <PimCommon/ConfigureImmutableWidgetUtils>
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <MailTransport/TransportManagementWidget>
 using MailTransport::TransportManagementWidget;
 #include <MailCommon/MailUtil>
 
+#include "kmail_debug.h"
 #include <AkonadiCore/agentfilterproxymodel.h>
-#include <AkonadiCore/agentinstancemodel.h>
-#include <AkonadiCore/agenttype.h>
-#include <AkonadiCore/agentmanager.h>
-#include <AkonadiWidgets/agenttypedialog.h>
-#include <AkonadiWidgets/AgentConfigurationDialog>
 #include <AkonadiCore/agentinstancecreatejob.h>
-#include <identity/identitypage.h>
-#include <KLDAP/LdapConfigureWidget>
-#include <QComboBox>
+#include <AkonadiCore/agentinstancemodel.h>
+#include <AkonadiCore/agentmanager.h>
+#include <AkonadiCore/agenttype.h>
+#include <AkonadiWidgets/AgentConfigurationDialog>
+#include <AkonadiWidgets/agenttypedialog.h>
 #include <KConfigGroup>
+#include <KLDAP/LdapConfigureWidget>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include "kmail_debug.h"
+#include <QComboBox>
+#include <identity/identitypage.h>
 
 #include <QAbstractItemView>
 #include <QGridLayout>
 #include <QGroupBox>
-#include <QMenu>
 #include <QLabel>
+#include <QMenu>
 #include <QProcess>
 #include <QVBoxLayout>
 
@@ -52,32 +52,31 @@ QString AccountsPage::helpAnchor() const
 AccountsPage::AccountsPage(QWidget *parent)
     : ConfigModuleWithTabs(parent)
 {
-    //Identity Tab:
-    auto *identityTab = new KMail::IdentityPage();
+    // Identity Tab:
+    auto identityTab = new KMail::IdentityPage();
     addTab(identityTab, i18nc("@title:tab Tab page where the user configures identities", "Identities"));
 
     //
     // "Receiving" tab:
     //
-    auto *receivingTab = new ReceivingTab();
+    auto receivingTab = new ReceivingTab();
     addTab(receivingTab, i18nc("@title:tab Tab page where the user configures accounts to receive mail", "Receiving"));
     connect(receivingTab, &ReceivingTab::accountListChanged, this, &AccountsPage::accountListChanged);
 
     //
     // "Sending" tab:
     //
-    auto *sendingTab = new SendingTab();
+    auto sendingTab = new SendingTab();
     addTab(sendingTab, i18nc("@title:tab Tab page where the user configures accounts to send mail", "Sending"));
 
     //
     // "Sending" tab:
     //
-    auto *ldapCompletionTab = new LdapCompetionTab();
+    auto ldapCompletionTab = new LdapCompetionTab();
     addTab(ldapCompletionTab, i18nc("@title:tab Tab page where the user configures ldap server", "LDAP server"));
 }
 
-AccountsPageSendingTab::~AccountsPageSendingTab()
-= default;
+AccountsPageSendingTab::~AccountsPageSendingTab() = default;
 
 QString AccountsPage::SendingTab::helpAnchor() const
 {
@@ -87,20 +86,20 @@ QString AccountsPage::SendingTab::helpAnchor() const
 AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
-    auto *vlay = new QVBoxLayout(this);
+    auto vlay = new QVBoxLayout(this);
     // label: zero stretch ### FIXME more
     vlay->addWidget(new QLabel(i18n("Outgoing accounts (add at least one):"), this));
 
-    auto *tmw = new TransportManagementWidget(this);
+    auto tmw = new TransportManagementWidget(this);
     tmw->layout()->setContentsMargins({});
     vlay->addWidget(tmw);
 
     // "Common options" groupbox:
-    QGroupBox *group = new QGroupBox(i18n("Common Options"), this);
+    auto group = new QGroupBox(i18n("Common Options"), this);
     vlay->addWidget(group);
 
     // a grid layout for the contents of the "common options" group box
-    auto *glay = new QGridLayout();
+    auto glay = new QGridLayout();
     group->setLayout(glay);
     glay->setColumnStretch(2, 10);
 
@@ -116,24 +115,19 @@ AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
     // "send on check" combo:
     mSendOnCheckCombo = new QComboBox(group);
     mSendOnCheckCombo->setEditable(false);
-    mSendOnCheckCombo->addItems(QStringList()
-                                << i18n("Never Automatically")
-                                << i18n("On Manual Mail Checks")
-                                << i18n("On All Mail Checks"));
+    mSendOnCheckCombo->addItems(QStringList() << i18n("Never Automatically") << i18n("On Manual Mail Checks") << i18n("On All Mail Checks"));
     glay->addWidget(mSendOnCheckCombo, 2, 1);
     connect(mSendOnCheckCombo, qOverload<int>(&QComboBox::activated), this, &AccountsPageSendingTab::slotEmitChanged);
 
     // "default send method" combo:
     mSendMethodCombo = new QComboBox(group);
     mSendMethodCombo->setEditable(false);
-    mSendMethodCombo->addItems(QStringList()
-                               << i18n("Send Now")
-                               << i18n("Send Later"));
+    mSendMethodCombo->addItems(QStringList() << i18n("Send Now") << i18n("Send Later"));
     glay->addWidget(mSendMethodCombo, 3, 1);
     connect(mSendMethodCombo, qOverload<int>(&QComboBox::activated), this, &AccountsPageSendingTab::slotEmitChanged);
 
     // labels:
-    QLabel *l = new QLabel(i18n("Send &messages in outbox folder:"), group);
+    auto l = new QLabel(i18n("Send &messages in outbox folder:"), group);
     l->setBuddy(mSendOnCheckCombo);
     glay->addWidget(l, 2, 0);
 
@@ -195,10 +189,8 @@ AccountsPageReceivingTab::AccountsPageReceivingTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
     const auto service = Akonadi::ServerManager::self()->agentServiceName(Akonadi::ServerManager::Agent, QStringLiteral("akonadi_newmailnotifier_agent"));
-    mNewMailNotifierInterface = new OrgFreedesktopAkonadiNewMailNotifierInterface(service,
-                                                                                  QStringLiteral("/NewMailNotifierAgent"),
-                                                                                  QDBusConnection::sessionBus(),
-                                                                                  this);
+    mNewMailNotifierInterface =
+        new OrgFreedesktopAkonadiNewMailNotifierInterface(service, QStringLiteral("/NewMailNotifierAgent"), QDBusConnection::sessionBus(), this);
     if (!mNewMailNotifierInterface->isValid()) {
         qCDebug(KMAIL_LOG) << " org.freedesktop.Akonadi.NewMailNotifierAgent not found. Please verify your installation";
         delete mNewMailNotifierInterface;
@@ -208,14 +200,15 @@ AccountsPageReceivingTab::AccountsPageReceivingTab(QWidget *parent)
 
     mAccountsReceiving.mAccountsReceiving->setMimeTypeFilter(QStringList() << KMime::Message::mimeType());
     mAccountsReceiving.mAccountsReceiving->setCapabilityFilter(QStringList() << QStringLiteral("Resource"));
-    mAccountsReceiving.mAccountsReceiving->setExcludeCapabilities(QStringList() << QStringLiteral("MailTransport") << QStringLiteral("Notes") << QStringLiteral("Autostart"));
+    mAccountsReceiving.mAccountsReceiving->setExcludeCapabilities(QStringList()
+                                                                  << QStringLiteral("MailTransport") << QStringLiteral("Notes") << QStringLiteral("Autostart"));
 
     KConfig specialMailCollection(QStringLiteral("specialmailcollectionsrc"));
     if (specialMailCollection.hasGroup(QStringLiteral("SpecialCollections"))) {
         KConfigGroup grp = specialMailCollection.group(QStringLiteral("SpecialCollections"));
         mAccountsReceiving.mAccountsReceiving->setSpecialCollectionIdentifier(grp.readEntry(QStringLiteral("DefaultResourceId")));
     }
-    auto *configDelegate = new ConfigAgentDelegate(mAccountsReceiving.mAccountsReceiving->view());
+    auto configDelegate = new ConfigAgentDelegate(mAccountsReceiving.mAccountsReceiving->view());
     mAccountsReceiving.mAccountsReceiving->setItemDelegate(configDelegate);
     connect(configDelegate, &ConfigAgentDelegate::optionsClicked, this, &AccountsPageReceivingTab::slotShowMailCheckMenu);
 
@@ -224,7 +217,7 @@ AccountsPageReceivingTab::AccountsPageReceivingTab(QWidget *parent)
     connect(mAccountsReceiving.mOtherNewMailActionsButton, &QAbstractButton::clicked, this, &AccountsPageReceivingTab::slotEditNotifications);
     connect(mAccountsReceiving.customizeAccountOrder, &QAbstractButton::clicked, this, &AccountsPageReceivingTab::slotCustomizeAccountOrder);
     mAccountsReceiving.mAccountsReceiving->disconnectAddAccountButton();
-    auto *accountMenu = new QMenu(this);
+    auto accountMenu = new QMenu(this);
     accountMenu->addAction(i18n("Add Mail Account..."), this, &AccountsPageReceivingTab::slotAddMailAccount);
     accountMenu->addAction(i18n("Custom Account..."), this, &AccountsPageReceivingTab::slotAddCustomAccount);
     mAccountsReceiving.mAccountsReceiving->addAccountButton()->setMenu(accountMenu);
@@ -243,12 +236,13 @@ void AccountsPageReceivingTab::slotAddCustomAccount()
 
 void AccountsPageReceivingTab::slotAddMailAccount()
 {
-    const QStringList lst = {QStringLiteral("--type"), QStringLiteral("message/rfc822") };
+    const QStringList lst = {QStringLiteral("--type"), QStringLiteral("message/rfc822")};
 
     const QString path = QStandardPaths::findExecutable(QStringLiteral("accountwizard"));
     if (!QProcess::startDetached(path, lst)) {
-        KMessageBox::error(this, i18n("Could not start the account wizard. "
-                                      "Please make sure you have AccountWizard properly installed."),
+        KMessageBox::error(this,
+                           i18n("Could not start the account wizard. "
+                                "Please make sure you have AccountWizard properly installed."),
                            i18n("Unable to start account wizard"));
     }
 }
@@ -298,7 +292,7 @@ void AccountsPageReceivingTab::slotShowMailCheckMenu(const QString &ident, const
     }
 
     if (!MailCommon::Util::isVirtualCollection(ident)) {
-        QAction *manualMailCheck = new QAction(i18nc("Label to a checkbox, so is either checked/unchecked", "Include in Manual Mail Check"), &menu);
+        auto manualMailCheck = new QAction(i18nc("Label to a checkbox, so is either checked/unchecked", "Include in Manual Mail Check"), &menu);
         manualMailCheck->setCheckable(true);
         manualMailCheck->setChecked(IncludeInManualChecks);
         manualMailCheck->setData(ident);
@@ -306,14 +300,14 @@ void AccountsPageReceivingTab::slotShowMailCheckMenu(const QString &ident, const
         connect(manualMailCheck, &QAction::toggled, this, &AccountsPageReceivingTab::slotIncludeInCheckChanged);
     }
 
-    QAction *switchOffline = new QAction(i18nc("Label to a checkbox, so is either checked/unchecked", "Switch offline on KMail Shutdown"), &menu);
+    auto switchOffline = new QAction(i18nc("Label to a checkbox, so is either checked/unchecked", "Switch offline on KMail Shutdown"), &menu);
     switchOffline->setCheckable(true);
     switchOffline->setChecked(OfflineOnShutdown);
     switchOffline->setData(ident);
     menu.addAction(switchOffline);
     connect(switchOffline, &QAction::toggled, this, &AccountsPageReceivingTab::slotOfflineOnShutdownChanged);
 
-    QAction *checkOnStartup = new QAction(i18n("Check mail on startup"), &menu);
+    auto checkOnStartup = new QAction(i18n("Check mail on startup"), &menu);
     checkOnStartup->setCheckable(true);
     checkOnStartup->setChecked(CheckOnStartup);
     checkOnStartup->setData(ident);
@@ -326,7 +320,7 @@ void AccountsPageReceivingTab::slotShowMailCheckMenu(const QString &ident, const
 
 void AccountsPageReceivingTab::slotCheckOnStatupChanged(bool checked)
 {
-    auto *action = qobject_cast< QAction * >(sender());
+    auto action = qobject_cast<QAction *>(sender());
     const QString ident = action->data().toString();
 
     QSharedPointer<RetrievalOptions> opts = mRetrievalHash.value(ident);
@@ -336,7 +330,7 @@ void AccountsPageReceivingTab::slotCheckOnStatupChanged(bool checked)
 
 void AccountsPageReceivingTab::slotIncludeInCheckChanged(bool checked)
 {
-    auto *action = qobject_cast< QAction * >(sender());
+    auto action = qobject_cast<QAction *>(sender());
     const QString ident = action->data().toString();
 
     QSharedPointer<RetrievalOptions> opts = mRetrievalHash.value(ident);
@@ -346,8 +340,8 @@ void AccountsPageReceivingTab::slotIncludeInCheckChanged(bool checked)
 
 void AccountsPageReceivingTab::slotOfflineOnShutdownChanged(bool checked)
 {
-    auto *action = qobject_cast< QAction * >(sender());
-    QString ident = action->data().toString();
+    auto action = qobject_cast<QAction *>(sender());
+    const QString ident = action->data().toString();
 
     QSharedPointer<RetrievalOptions> opts = mRetrievalHash.value(ident);
     opts->OfflineOnShutdown = checked;
@@ -379,8 +373,8 @@ void AccountsPage::ReceivingTab::save()
     }
 
     const QString resourceGroupPattern(QStringLiteral("Resource %1"));
-    QHash<QString, QSharedPointer<RetrievalOptions> >::const_iterator it = mRetrievalHash.cbegin();
-    const QHash<QString, QSharedPointer<RetrievalOptions> >::const_iterator itEnd = mRetrievalHash.cend();
+    QHash<QString, QSharedPointer<RetrievalOptions>>::const_iterator it = mRetrievalHash.cbegin();
+    const QHash<QString, QSharedPointer<RetrievalOptions>>::const_iterator itEnd = mRetrievalHash.cend();
     for (; it != itEnd; ++it) {
         KConfigGroup group;
         KConfig *conf = nullptr;
@@ -401,7 +395,7 @@ void AccountsPage::ReceivingTab::save()
 LdapCompetionTab::LdapCompetionTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setContentsMargins({});
 
     mLdapConfigureWidget = new KLDAP::LdapConfigureWidget(this);
@@ -410,8 +404,7 @@ LdapCompetionTab::LdapCompetionTab(QWidget *parent)
     connect(mLdapConfigureWidget, &KLDAP::LdapConfigureWidget::changed, this, qOverload<bool>(&LdapCompetionTab::changed));
 }
 
-LdapCompetionTab::~LdapCompetionTab()
-= default;
+LdapCompetionTab::~LdapCompetionTab() = default;
 
 QString LdapCompetionTab::helpAnchor() const
 {
