@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,25 +7,27 @@
 #include "configuresecuritypage.h"
 #include <PimCommon/ConfigureImmutableWidgetUtils>
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
-#include <MessageViewer/MessageViewerSettings>
-#include <MessageComposer/MessageComposerSettings>
-#include <WebEngineViewer/CheckPhishingUrlCache>
-#include <MailCommon/FolderSettings>
 #include "settings/kmailsettings.h"
+#include <MailCommon/FolderSettings>
+#include <MessageComposer/MessageComposerSettings>
+#include <MessageViewer/MessageViewerSettings>
+#include <MessageViewer/RemoteContentConfigureDialog>
+#include <WebEngineViewer/CheckPhishingUrlCache>
 
 #include "kmkernel.h"
 
-#include <QGpgME/Protocol>
-#include <QGpgME/CryptoConfig>
 #include <Libkleo/KeyRequester>
 #include <Libkleo/KeySelectionDialog>
+#include <QGpgME/CryptoConfig>
+#include <QGpgME/Protocol>
 
+#include "kmail_debug.h"
 #include <KLocalizedString>
 #include <KMessageBox>
-#include "kmail_debug.h"
 
 #include <QButtonGroup>
 #include <QDBusConnection>
+#include <QPointer>
 #include <QWhatsThis>
 
 QString SecurityPage::helpAnchor() const
@@ -39,7 +41,7 @@ SecurityPage::SecurityPage(QWidget *parent)
     //
     // "Reading" tab:
     //
-    auto *generalTab = new ReadingTab();
+    auto generalTab = new ReadingTab();
     addTab(generalTab, i18n("Reading"));
 
     addTab(new MDNTab(), i18n("Message Disposition Notifications"));
@@ -47,19 +49,19 @@ SecurityPage::SecurityPage(QWidget *parent)
     //
     // "Composing" tab:
     //
-    auto *composerCryptoTab = new ComposerCryptoTab();
+    auto composerCryptoTab = new ComposerCryptoTab();
     addTab(composerCryptoTab, i18n("Composing"));
 
     //
     // "Warnings" tab:
     //
-    auto *warningTab = new WarningTab();
+    auto warningTab = new WarningTab();
     addTab(warningTab, i18n("Miscellaneous"));
 
     //
     // "S/MIME Validation" tab:
     //
-    auto *sMimeTab = new SMimeTab();
+    auto sMimeTab = new SMimeTab();
     addTab(sMimeTab, i18n("S/MIME Validation"));
 }
 
@@ -73,6 +75,7 @@ SecurityPageGeneralTab::SecurityPageGeneralTab(QWidget *parent)
 {
     mSGTab.setupUi(this);
 
+    connect(mSGTab.mConfigureExternalReference, &QPushButton::clicked, this, &SecurityPageGeneralTab::slotOpenExternalReferenceExceptions);
     connect(mSGTab.mHtmlMailCheck, &QCheckBox::stateChanged, this, &SecurityPageGeneralTab::slotEmitChanged);
     connect(mSGTab.mExternalReferences, &QCheckBox::stateChanged, this, &SecurityPageGeneralTab::slotEmitChanged);
     connect(mSGTab.labelWarnHTML, &QLabel::linkActivated, this, &SecurityPageGeneralTab::slotLinkClicked);
@@ -90,6 +93,13 @@ SecurityPageGeneralTab::SecurityPageGeneralTab(QWidget *parent)
     mSGTab.scamWhiteList->setRemoveDialogLabel(i18n("Do you want to remove this email address?"));
 }
 
+void SecurityPageGeneralTab::slotOpenExternalReferenceExceptions()
+{
+    QPointer<MessageViewer::RemoteContentConfigureDialog> dlg = new MessageViewer::RemoteContentConfigureDialog(this);
+    dlg->exec();
+    delete dlg;
+}
+
 void SecurityPageGeneralTab::slotLinkClicked(const QString &link)
 {
     if (link == QLatin1String("whatsthis1")) {
@@ -115,15 +125,20 @@ void SecurityPage::ReadingTab::doLoadOther()
 void SecurityPage::ReadingTab::save()
 {
     if (MessageViewer::MessageViewerSettings::self()->htmlMail() != mSGTab.mHtmlMailCheck->isChecked()) {
-        if (KMessageBox::warningContinueCancel(this, i18n("Changing the global "
-                                                          "HTML setting will override all folder specific values."), QString(),
-                                               KStandardGuiItem::cont(), KStandardGuiItem::cancel(), QStringLiteral("htmlMailOverride")) == KMessageBox::Continue) {
+        if (KMessageBox::warningContinueCancel(this,
+                                               i18n("Changing the global "
+                                                    "HTML setting will override all folder specific values."),
+                                               QString(),
+                                               KStandardGuiItem::cont(),
+                                               KStandardGuiItem::cancel(),
+                                               QStringLiteral("htmlMailOverride"))
+            == KMessageBox::Continue) {
             saveCheckBox(mSGTab.mHtmlMailCheck, MessageViewer::MessageViewerSettings::self()->htmlMailItem());
             if (kmkernel) {
                 const auto allFolders = kmkernel->allFolders();
                 for (const Akonadi::Collection &collection : allFolders) {
                     KConfigGroup config(KMKernel::self()->config(), MailCommon::FolderSettings::configGroupName(collection));
-                    //Old config
+                    // Old config
                     config.deleteEntry("htmlMailOverride");
                     config.deleteEntry("displayFormatOverride");
                     MailCommon::FolderSettings::resetHtmlFormat();
@@ -294,8 +309,7 @@ void SecurityPage::WarningTab::doLoadFromGlobalSettings()
 
     // The "-int" part of the key name is because there used to be a separate boolean
     // config entry for enabling/disabling. This is done with the single bool value now.
-    mWidget->warnGroupBox->setChecked(
-        MessageComposer::MessageComposerSettings::self()->cryptoWarnWhenNearExpire());
+    mWidget->warnGroupBox->setChecked(MessageComposer::MessageComposerSettings::self()->cryptoWarnWhenNearExpire());
 
     loadWidget(mWidget->mWarnSignKeyExpiresSB, MessageComposer::MessageComposerSettings::self()->cryptoWarnSignKeyNearExpiryThresholdDaysItem());
     loadWidget(mWidget->mWarnSignChainCertExpiresSB, MessageComposer::MessageComposerSettings::self()->cryptoWarnSignChaincertNearExpiryThresholdDaysItem());
@@ -312,8 +326,7 @@ void SecurityPage::WarningTab::doLoadOther()
 
     // The "-int" part of the key name is because there used to be a separate boolean
     // config entry for enabling/disabling. This is done with the single bool value now.
-    mWidget->warnGroupBox->setChecked(
-        MessageComposer::MessageComposerSettings::self()->cryptoWarnWhenNearExpire());
+    mWidget->warnGroupBox->setChecked(MessageComposer::MessageComposerSettings::self()->cryptoWarnWhenNearExpire());
 
     loadWidget(mWidget->mWarnSignKeyExpiresSB, MessageComposer::MessageComposerSettings::self()->cryptoWarnSignKeyNearExpiryThresholdDaysItem());
     mWidget->mWarnSignKeyExpiresSB->setSuffix(ki18np(" day", " days"));
@@ -338,8 +351,7 @@ void SecurityPage::WarningTab::save()
     saveCheckBox(mWidget->warnUnencryptedCB, MessageComposer::MessageComposerSettings::self()->cryptoWarningUnencryptedItem());
     saveCheckBox(mWidget->mWarnUnsigned, MessageComposer::MessageComposerSettings::self()->cryptoWarningUnsignedItem());
 
-    MessageComposer::MessageComposerSettings::self()->setCryptoWarnWhenNearExpire(
-        mWidget->warnGroupBox->isChecked());
+    MessageComposer::MessageComposerSettings::self()->setCryptoWarnWhenNearExpire(mWidget->warnGroupBox->isChecked());
 
     saveSpinBox(mWidget->mWarnSignKeyExpiresSB, MessageComposer::MessageComposerSettings::self()->cryptoWarnSignKeyNearExpiryThresholdDaysItem());
     saveSpinBox(mWidget->mWarnSignChainCertExpiresSB, MessageComposer::MessageComposerSettings::self()->cryptoWarnSignChaincertNearExpiryThresholdDaysItem());
@@ -360,7 +372,7 @@ void SecurityPage::WarningTab::slotConfigureGnupg()
     QPointer<GpgSettingsDialog> dlg(new GpgSettingsDialog(this));
     KPageWidgetItem *page = dlg->addModule(QStringLiteral("kleopatra_config_gnupgsystem"));
     if (!page) {
-        QLabel *info = new QLabel(i18n("The module is missing. Please verify your installation. This module is provided by Kleopatra."), this);
+        auto info = new QLabel(i18n("The module is missing. Please verify your installation. This module is provided by Kleopatra."), this);
         QFont font = info->font();
         font.setBold(true);
         info->setFont(font);
@@ -383,17 +395,14 @@ SecurityPageSMimeTab::SecurityPageSMimeTab(QWidget *parent)
     mWidget->setupUi(this);
 
     // Button-group for exclusive radiobuttons
-    auto *bg = new QButtonGroup(this);
+    auto bg = new QButtonGroup(this);
     bg->addButton(mWidget->CRLRB);
     bg->addButton(mWidget->OCSPRB);
 
     // Settings for the keyrequester custom widget
-    mWidget->OCSPResponderSignature->setAllowedKeys(
-        Kleo::KeySelectionDialog::SMIMEKeys
-        | Kleo::KeySelectionDialog::TrustedKeys
-        | Kleo::KeySelectionDialog::ValidKeys
-        | Kleo::KeySelectionDialog::SigningKeys
-        | Kleo::KeySelectionDialog::PublicKeys);
+    mWidget->OCSPResponderSignature->setAllowedKeys(Kleo::KeySelectionDialog::SMIMEKeys | Kleo::KeySelectionDialog::TrustedKeys
+                                                    | Kleo::KeySelectionDialog::ValidKeys | Kleo::KeySelectionDialog::SigningKeys
+                                                    | Kleo::KeySelectionDialog::PublicKeys);
     mWidget->OCSPResponderSignature->setMultipleKeysEnabled(false);
 
     mConfig = QGpgME::cryptoConfig();
@@ -420,7 +429,7 @@ SecurityPageSMimeTab::SecurityPageSMimeTab(QWidget *parent)
     connect(mWidget->ignoreHTTPDPCB, &QCheckBox::toggled, this, &SecurityPageSMimeTab::slotUpdateHTTPActions);
 
     // Button-group for exclusive radiobuttons
-    auto *bgHTTPProxy = new QButtonGroup(this);
+    auto bgHTTPProxy = new QButtonGroup(this);
     bgHTTPProxy->addButton(mWidget->honorHTTPProxyRB);
     bgHTTPProxy->addButton(mWidget->useCustomHTTPProxyRB);
 
@@ -452,24 +461,51 @@ struct SMIMECryptoConfigEntries {
         : mConfig(config)
     {
         // Checkboxes
-        mCheckUsingOCSPConfigEntry = configEntry(QStringLiteral("gpgsm"), QStringLiteral("Security"), QStringLiteral("enable-ocsp"), QGpgME::CryptoConfigEntry::ArgType_None, false);
-        mEnableOCSPsendingConfigEntry = configEntry(QStringLiteral("dirmngr"), QStringLiteral("OCSP"), QStringLiteral("allow-ocsp"), QGpgME::CryptoConfigEntry::ArgType_None, false);
-        mDoNotCheckCertPolicyConfigEntry = configEntry(QStringLiteral("gpgsm"), QStringLiteral("Security"), QStringLiteral("disable-policy-checks"), QGpgME::CryptoConfigEntry::ArgType_None, false);
-        mNeverConsultConfigEntry = configEntry(QStringLiteral("gpgsm"), QStringLiteral("Security"), QStringLiteral("disable-crl-checks"), QGpgME::CryptoConfigEntry::ArgType_None, false);
-        mFetchMissingConfigEntry = configEntry(QStringLiteral("gpgsm"), QStringLiteral("Security"), QStringLiteral("auto-issuer-key-retrieve"), QGpgME::CryptoConfigEntry::ArgType_None, false);
+        mCheckUsingOCSPConfigEntry =
+            configEntry(QStringLiteral("gpgsm"), QStringLiteral("Security"), QStringLiteral("enable-ocsp"), QGpgME::CryptoConfigEntry::ArgType_None, false);
+        mEnableOCSPsendingConfigEntry =
+            configEntry(QStringLiteral("dirmngr"), QStringLiteral("OCSP"), QStringLiteral("allow-ocsp"), QGpgME::CryptoConfigEntry::ArgType_None, false);
+        mDoNotCheckCertPolicyConfigEntry = configEntry(QStringLiteral("gpgsm"),
+                                                       QStringLiteral("Security"),
+                                                       QStringLiteral("disable-policy-checks"),
+                                                       QGpgME::CryptoConfigEntry::ArgType_None,
+                                                       false);
+        mNeverConsultConfigEntry = configEntry(QStringLiteral("gpgsm"),
+                                               QStringLiteral("Security"),
+                                               QStringLiteral("disable-crl-checks"),
+                                               QGpgME::CryptoConfigEntry::ArgType_None,
+                                               false);
+        mFetchMissingConfigEntry = configEntry(QStringLiteral("gpgsm"),
+                                               QStringLiteral("Security"),
+                                               QStringLiteral("auto-issuer-key-retrieve"),
+                                               QGpgME::CryptoConfigEntry::ArgType_None,
+                                               false);
         // dirmngr-0.9.0 options
-        mIgnoreServiceURLEntry = configEntry(QStringLiteral("dirmngr"), QStringLiteral("OCSP"), QStringLiteral("ignore-ocsp-service-url"), QGpgME::CryptoConfigEntry::ArgType_None, false);
-        mIgnoreHTTPDPEntry = configEntry(QStringLiteral("dirmngr"), QStringLiteral("HTTP"), QStringLiteral("ignore-http-dp"), QGpgME::CryptoConfigEntry::ArgType_None, false);
-        mDisableHTTPEntry = configEntry(QStringLiteral("dirmngr"), QStringLiteral("HTTP"), QStringLiteral("disable-http"), QGpgME::CryptoConfigEntry::ArgType_None, false);
-        mHonorHTTPProxy = configEntry(QStringLiteral("dirmngr"), QStringLiteral("HTTP"), QStringLiteral("honor-http-proxy"), QGpgME::CryptoConfigEntry::ArgType_None, false);
+        mIgnoreServiceURLEntry = configEntry(QStringLiteral("dirmngr"),
+                                             QStringLiteral("OCSP"),
+                                             QStringLiteral("ignore-ocsp-service-url"),
+                                             QGpgME::CryptoConfigEntry::ArgType_None,
+                                             false);
+        mIgnoreHTTPDPEntry =
+            configEntry(QStringLiteral("dirmngr"), QStringLiteral("HTTP"), QStringLiteral("ignore-http-dp"), QGpgME::CryptoConfigEntry::ArgType_None, false);
+        mDisableHTTPEntry =
+            configEntry(QStringLiteral("dirmngr"), QStringLiteral("HTTP"), QStringLiteral("disable-http"), QGpgME::CryptoConfigEntry::ArgType_None, false);
+        mHonorHTTPProxy =
+            configEntry(QStringLiteral("dirmngr"), QStringLiteral("HTTP"), QStringLiteral("honor-http-proxy"), QGpgME::CryptoConfigEntry::ArgType_None, false);
 
-        mIgnoreLDAPDPEntry = configEntry(QStringLiteral("dirmngr"), QStringLiteral("LDAP"), QStringLiteral("ignore-ldap-dp"), QGpgME::CryptoConfigEntry::ArgType_None, false);
-        mDisableLDAPEntry = configEntry(QStringLiteral("dirmngr"), QStringLiteral("LDAP"), QStringLiteral("disable-ldap"), QGpgME::CryptoConfigEntry::ArgType_None, false);
+        mIgnoreLDAPDPEntry =
+            configEntry(QStringLiteral("dirmngr"), QStringLiteral("LDAP"), QStringLiteral("ignore-ldap-dp"), QGpgME::CryptoConfigEntry::ArgType_None, false);
+        mDisableLDAPEntry =
+            configEntry(QStringLiteral("dirmngr"), QStringLiteral("LDAP"), QStringLiteral("disable-ldap"), QGpgME::CryptoConfigEntry::ArgType_None, false);
         // Other widgets
-        mOCSPResponderURLConfigEntry = configEntry(QStringLiteral("dirmngr"), QStringLiteral("OCSP"), QStringLiteral("ocsp-responder"), QGpgME::CryptoConfigEntry::ArgType_String, false);
-        mOCSPResponderSignature = configEntry(QStringLiteral("dirmngr"), QStringLiteral("OCSP"), QStringLiteral("ocsp-signer"), QGpgME::CryptoConfigEntry::ArgType_String, false);
-        mCustomHTTPProxy = configEntry(QStringLiteral("dirmngr"), QStringLiteral("HTTP"), QStringLiteral("http-proxy"), QGpgME::CryptoConfigEntry::ArgType_String, false);
-        mCustomLDAPProxy = configEntry(QStringLiteral("dirmngr"), QStringLiteral("LDAP"), QStringLiteral("ldap-proxy"), QGpgME::CryptoConfigEntry::ArgType_String, false);
+        mOCSPResponderURLConfigEntry =
+            configEntry(QStringLiteral("dirmngr"), QStringLiteral("OCSP"), QStringLiteral("ocsp-responder"), QGpgME::CryptoConfigEntry::ArgType_String, false);
+        mOCSPResponderSignature =
+            configEntry(QStringLiteral("dirmngr"), QStringLiteral("OCSP"), QStringLiteral("ocsp-signer"), QGpgME::CryptoConfigEntry::ArgType_String, false);
+        mCustomHTTPProxy =
+            configEntry(QStringLiteral("dirmngr"), QStringLiteral("HTTP"), QStringLiteral("http-proxy"), QGpgME::CryptoConfigEntry::ArgType_String, false);
+        mCustomLDAPProxy =
+            configEntry(QStringLiteral("dirmngr"), QStringLiteral("LDAP"), QStringLiteral("ldap-proxy"), QGpgME::CryptoConfigEntry::ArgType_String, false);
     }
 
     QGpgME::CryptoConfigEntry *configEntry(const QString &componentName, const QString &groupName, const QString &entryName, int argType, bool isList);
@@ -574,15 +610,13 @@ void SecurityPage::SMimeTab::slotUpdateHTTPActions()
     mWidget->ignoreHTTPDPCB->setEnabled(!mWidget->disableHTTPCB->isChecked());
 
     // The proxy settings only make sense when "Ignore HTTP CRL DPs of certificate" is checked.
-    bool enableProxySettings = !mWidget->disableHTTPCB->isChecked()
-                               && mWidget->ignoreHTTPDPCB->isChecked();
+    bool enableProxySettings = !mWidget->disableHTTPCB->isChecked() && mWidget->ignoreHTTPDPCB->isChecked();
     mWidget->systemHTTPProxy->setEnabled(enableProxySettings);
     mWidget->useCustomHTTPProxyRB->setEnabled(enableProxySettings);
     mWidget->honorHTTPProxyRB->setEnabled(enableProxySettings);
     mWidget->customHTTPProxy->setEnabled(enableProxySettings && mWidget->useCustomHTTPProxyRB->isChecked());
 
-    if (!mWidget->useCustomHTTPProxyRB->isChecked()
-        && !mWidget->honorHTTPProxyRB->isChecked()) {
+    if (!mWidget->useCustomHTTPProxyRB->isChecked() && !mWidget->honorHTTPProxyRB->isChecked()) {
         mWidget->honorHTTPProxyRB->setChecked(true);
     }
 }
@@ -628,7 +662,7 @@ void SecurityPage::SMimeTab::save()
         e.mOCSPResponderSignature->setStringValue(txt);
     }
 
-    //dirmngr-0.9.0 options
+    // dirmngr-0.9.0 options
     saveCheckBoxToKleoEntry(mWidget->ignoreServiceURLCB, e.mIgnoreServiceURLEntry);
     saveCheckBoxToKleoEntry(mWidget->ignoreHTTPDPCB, e.mIgnoreHTTPDPEntry);
     saveCheckBoxToKleoEntry(mWidget->disableHTTPCB, e.mDisableHTTPEntry);
@@ -653,7 +687,11 @@ void SecurityPage::SMimeTab::save()
     mConfig->sync(true);
 }
 
-QGpgME::CryptoConfigEntry *SMIMECryptoConfigEntries::configEntry(const QString &componentName, const QString &groupName, const QString &entryName, int /*Kleo::CryptoConfigEntry::ArgType*/ argType, bool isList)
+QGpgME::CryptoConfigEntry *SMIMECryptoConfigEntries::configEntry(const QString &componentName,
+                                                                 const QString &groupName,
+                                                                 const QString &entryName,
+                                                                 int /*Kleo::CryptoConfigEntry::ArgType*/ argType,
+                                                                 bool isList)
 {
     QGpgME::CryptoConfigEntry *entry = mConfig->entry(componentName, groupName, entryName);
     if (!entry) {
@@ -661,7 +699,10 @@ QGpgME::CryptoConfigEntry *SMIMECryptoConfigEntries::configEntry(const QString &
         return nullptr;
     }
     if (entry->argType() != argType || entry->isList() != isList) {
-        qCWarning(KMAIL_LOG) << QStringLiteral("Backend error: gpgconf has wrong type for %1/%2/%3: %4 %5").arg(componentName, groupName, entryName).arg(entry->argType()).arg(entry->isList());
+        qCWarning(KMAIL_LOG) << QStringLiteral("Backend error: gpgconf has wrong type for %1/%2/%3: %4 %5")
+                                    .arg(componentName, groupName, entryName)
+                                    .arg(entry->argType())
+                                    .arg(entry->isList());
         return nullptr;
     }
     return entry;
