@@ -1,6 +1,6 @@
 /*
  * This file is part of KMail.
- * SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
  * SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
  *
  * Parts based on KMail code by:
@@ -13,17 +13,19 @@
 #ifndef KMAIL_ATTACHMENTVIEW_H
 #define KMAIL_ATTACHMENTVIEW_H
 
-#include <QTreeView>
 #include <KConfigGroup>
+#include <QTreeView>
 
 class QContextMenuEvent;
 class QToolButton;
 class QLabel;
-namespace MessageComposer {
+namespace MessageComposer
+{
 class AttachmentModel;
 }
 
-namespace KMail {
+namespace KMail
+{
 class AttachmentView : public QTreeView
 {
     Q_OBJECT
@@ -62,10 +64,10 @@ Q_SIGNALS:
     void modified(bool);
 
 private:
-    MessageComposer::AttachmentModel *mModel = nullptr;
-    QToolButton *mToolButton = nullptr;
-    QLabel *mInfoAttachment = nullptr;
-    QWidget *mWidget = nullptr;
+    MessageComposer::AttachmentModel *const mModel;
+    QToolButton *const mToolButton;
+    QLabel *const mInfoAttachment;
+    QWidget *const mWidget;
     KConfigGroup grp;
 };
 } // namespace KMail
