@@ -10,8 +10,8 @@
 
 #include "identitylistview.h"
 
-#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
 #include <KIdentityManagement/kidentitymanagement/identity.h>
+#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
 
 #ifndef KCM_KPIMIDENTITIES_STANDALONE
 #include "kmkernel.h"
@@ -73,10 +73,12 @@ void IdentityListViewItem::init(const KIdentityManagement::Identity &ident)
 {
     if (ident.isDefault()) {
         // Add "(Default)" to the end of the default identity's name:
-        setText(0, i18nc("%1: identity name. Used in the config "
-                         "dialog, section Identity, to indicate the "
-                         "default identity", "%1 (Default)",
-                         ident.identityName()));
+        setText(0,
+                i18nc("%1: identity name. Used in the config "
+                      "dialog, section Identity, to indicate the "
+                      "default identity",
+                      "%1 (Default)",
+                      ident.identityName()));
         QFont fontItem(font(0));
         fontItem.setBold(true);
         setFont(0, fontItem);
@@ -141,7 +143,7 @@ void IdentityListView::commitData(QWidget *editor)
     qCDebug(KMAIL_LOG) << "after editing";
 
     if (!selectedItems().isEmpty()) {
-        auto *edit = qobject_cast<QLineEdit *>(editor);
+        auto edit = qobject_cast<QLineEdit *>(editor);
         if (edit) {
             IdentityListViewItem *item = dynamic_cast<IdentityListViewItem *>(selectedItems().at(0));
             const QString text = edit->text();
@@ -171,8 +173,8 @@ void IdentityListView::startDrag(Qt::DropActions /*supportedActions*/)
         return;
     }
 
-    auto *drag = new QDrag(viewport());
-    auto *md = new QMimeData;
+    auto drag = new QDrag(viewport());
+    auto md = new QMimeData;
     drag->setMimeData(md);
     item->identity().populateMimeData(md);
     drag->setPixmap(QIcon::fromTheme(QStringLiteral("user-identity")).pixmap(16, 16));
