@@ -19,16 +19,18 @@ class QUrl;
 
 class QCheckBox;
 class QLabel;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
-namespace KMail {
+namespace KMail
+{
 class XFaceConfigurator : public QWidget
 {
     Q_OBJECT
 public:
     explicit XFaceConfigurator(QWidget *parent = nullptr);
-    ~XFaceConfigurator();
+    ~XFaceConfigurator() override;
 
     Q_REQUIRED_RESULT bool isXFaceEnabled() const;
     void setXFaceEnabled(bool enable);
