@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "composenewmessagejob.h"
-#include "kmkernel.h"
 #include "composer.h"
 #include "editor/kmcomposerwin.h"
+#include "kmkernel.h"
 
 #include <KMime/Message>
 #include <MessageComposer/MessageHelper>
@@ -18,8 +18,7 @@ ComposeNewMessageJob::ComposeNewMessageJob(QObject *parent)
 {
 }
 
-ComposeNewMessageJob::~ComposeNewMessageJob()
-= default;
+ComposeNewMessageJob::~ComposeNewMessageJob() = default;
 
 void ComposeNewMessageJob::setCurrentCollection(const Akonadi::Collection &col)
 {
@@ -32,7 +31,7 @@ void ComposeNewMessageJob::start()
 
     mIdentity = mFolder ? mFolder->identity() : 0;
     MessageHelper::initHeader(mMsg, KMKernel::self()->identityManager(), mIdentity);
-    auto *parser = new TemplateParser::TemplateParserJob(mMsg, TemplateParser::TemplateParserJob::NewMessage, this);
+    auto parser = new TemplateParser::TemplateParserJob(mMsg, TemplateParser::TemplateParserJob::NewMessage, this);
     connect(parser, &TemplateParser::TemplateParserJob::parsingDone, this, &ComposeNewMessageJob::slotOpenComposer);
     parser->setIdentityManager(KMKernel::self()->identityManager());
     if (mFolder) {
