@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,20 +7,21 @@
 #ifndef COMPOSENEWMESSAGEJOB_H
 #define COMPOSENEWMESSAGEJOB_H
 
+#include <MailCommon/FolderSettings>
 #include <QObject>
 #include <QSharedPointer>
-#include <MailCommon/FolderSettings>
 
 class ComposeNewMessageJob : public QObject
 {
     Q_OBJECT
 public:
     explicit ComposeNewMessageJob(QObject *parent = nullptr);
-    ~ComposeNewMessageJob();
+    ~ComposeNewMessageJob() override;
     void start();
     void setFolderSettings(const QSharedPointer<MailCommon::FolderSettings> &folder);
 
     void setCurrentCollection(const Akonadi::Collection &col);
+
 private:
     Q_DISABLE_COPY(ComposeNewMessageJob)
     void slotOpenComposer(bool forceCursorPosition);
