@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,16 +7,29 @@
 #ifndef FILLCOMPOSERJOB_H
 #define FILLCOMPOSERJOB_H
 
-#include <QObject>
 #include <KMime/Message>
+#include <QObject>
 
-struct FillComposerJobSettings
-{
-    FillComposerJobSettings()
-    = default;
+struct FillComposerJobSettings {
+    FillComposerJobSettings() = default;
 
-    FillComposerJobSettings(bool hidden, const QString &to, const QString &cc, const QString &bcc, const QString &subject, const QString &body, const QString &attachName, const QByteArray &attachCte, const QByteArray &attachData, const QByteArray &attachType, const QByteArray &attachSubType,
-                            const QByteArray &attachParamAttr, const QString &attachParamValue, const QByteArray &attachContDisp, const QByteArray &attachCharset, unsigned int identity, bool forceShowWindow)
+    FillComposerJobSettings(bool hidden,
+                            const QString &to,
+                            const QString &cc,
+                            const QString &bcc,
+                            const QString &subject,
+                            const QString &body,
+                            const QString &attachName,
+                            const QByteArray &attachCte,
+                            const QByteArray &attachData,
+                            const QByteArray &attachType,
+                            const QByteArray &attachSubType,
+                            const QByteArray &attachParamAttr,
+                            const QString &attachParamValue,
+                            const QByteArray &attachContDisp,
+                            const QByteArray &attachCharset,
+                            unsigned int identity,
+                            bool forceShowWindow)
         : mTo(to)
         , mCc(cc)
         , mBcc(bcc)
