@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,13 +7,11 @@
 #ifndef OPENCOMPOSERHIDDENJOB_H
 #define OPENCOMPOSERHIDDENJOB_H
 
-#include <QObject>
 #include <KMime/Message>
+#include <QObject>
 
-struct OpenComposerHiddenJobSettings
-{
-    OpenComposerHiddenJobSettings()
-    = default;
+struct OpenComposerHiddenJobSettings {
+    OpenComposerHiddenJobSettings() = default;
 
     OpenComposerHiddenJobSettings(const QString &to, const QString &cc, const QString &bcc, const QString &subject, const QString &body, bool hidden)
         : mTo(to)
@@ -38,7 +36,7 @@ class OpenComposerHiddenJob : public QObject
     Q_OBJECT
 public:
     explicit OpenComposerHiddenJob(QObject *parent = nullptr);
-    ~OpenComposerHiddenJob();
+    ~OpenComposerHiddenJob() override;
     void start();
     void setSettings(const OpenComposerHiddenJobSettings &settings);
 
