@@ -1,22 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "opencomposerjob.h"
+#include "composer.h"
 #include "kmail_debug.h"
 #include "kmkernel.h"
-#include "composer.h"
-#include <MessageCore/StringUtil>
-#include <TemplateParser/TemplateParserJob>
-#include <KIdentityManagement/IdentityManager>
 #include <KIdentityManagement/Identity>
-#include <MessageComposer/MessageHelper>
-#include <QMimeDatabase>
-#include <QFile>
-#include <KMessageBox>
+#include <KIdentityManagement/IdentityManager>
 #include <KLocalizedString>
+#include <KMessageBox>
+#include <MessageComposer/MessageHelper>
+#include <MessageCore/StringUtil>
+#include <QFile>
+#include <QMimeDatabase>
+#include <TemplateParser/TemplateParserJob>
 
 OpenComposerJob::OpenComposerJob(QObject *parent)
     : QObject(parent)
@@ -28,8 +28,7 @@ void OpenComposerJob::setOpenComposerSettings(const OpenComposerSettings &openCo
     mOpenComposerSettings = openComposerSettings;
 }
 
-OpenComposerJob::~OpenComposerJob()
-= default;
+OpenComposerJob::~OpenComposerJob() = default;
 
 void OpenComposerJob::start()
 {
@@ -82,7 +81,7 @@ void OpenComposerJob::start()
             mMsg->setBody(str);
             slotOpenComposer();
         } else {
-            auto *parser = new TemplateParser::TemplateParserJob(mMsg, TemplateParser::TemplateParserJob::NewMessage);
+            auto parser = new TemplateParser::TemplateParserJob(mMsg, TemplateParser::TemplateParserJob::NewMessage);
             connect(parser, &TemplateParser::TemplateParserJob::parsingDone, this, &OpenComposerJob::slotOpenComposer);
             parser->setIdentityManager(KMKernel::self()->identityManager());
             parser->process(mMsg);
@@ -94,7 +93,7 @@ void OpenComposerJob::start()
         mMsg->parse();
         slotOpenComposer();
     } else {
-        auto *parser = new TemplateParser::TemplateParserJob(mMsg, TemplateParser::TemplateParserJob::NewMessage);
+        auto parser = new TemplateParser::TemplateParserJob(mMsg, TemplateParser::TemplateParserJob::NewMessage);
         connect(parser, &TemplateParser::TemplateParserJob::parsingDone, this, &OpenComposerJob::slotOpenComposer);
         parser->setIdentityManager(KMKernel::self()->identityManager());
         parser->process(mMsg);
@@ -113,7 +112,8 @@ void OpenComposerJob::slotOpenComposer()
     for (QList<QUrl>::ConstIterator it = attachURLs.constBegin(); it != endAttachment; ++it) {
         QMimeDatabase mimeDb;
         if (mimeDb.mimeTypeForUrl(*it).name() == QLatin1String("inode/directory")) {
-            if (KMessageBox::questionYesNo(nullptr, i18n("Do you want to attach this folder \"%1\"?", (*it).toDisplayString()), i18n("Attach Folder")) == KMessageBox::No) {
+            if (KMessageBox::questionYesNo(nullptr, i18n("Do you want to attach this folder \"%1\"?", (*it).toDisplayString()), i18n("Attach Folder"))
+                == KMessageBox::No) {
                 continue;
             }
         }
