@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "removeduplicatemailjob.h"
 
-#include <Libkdepim/ProgressManager>
+#include <AkonadiCore/Collection>
+#include <AkonadiCore/EntityTreeModel>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <AkonadiCore/Collection>
+#include <Libkdepim/ProgressManager>
 #include <akonadi/kmime/removeduplicatesjob.h>
-#include <AkonadiCore/EntityTreeModel>
 
 #include <QItemSelectionModel>
 Q_DECLARE_METATYPE(KPIM::ProgressItem *)
@@ -24,8 +24,7 @@ RemoveDuplicateMailJob::RemoveDuplicateMailJob(QItemSelectionModel *selectionMod
 {
 }
 
-RemoveDuplicateMailJob::~RemoveDuplicateMailJob()
-= default;
+RemoveDuplicateMailJob::~RemoveDuplicateMailJob() = default;
 
 void RemoveDuplicateMailJob::start()
 {
@@ -43,7 +42,7 @@ void RemoveDuplicateMailJob::start()
         }
     }
 
-    auto *job = new Akonadi::RemoveDuplicatesJob(collections, this);
+    auto job = new Akonadi::RemoveDuplicatesJob(collections, this);
     job->setProperty("ProgressItem", QVariant::fromValue(item));
     item->setProperty("RemoveDuplicatesJob", QVariant::fromValue(job));
     connect(job, &KJob::finished, this, &RemoveDuplicateMailJob::slotRemoveDuplicatesDone);
