@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef UNDOSENDCREATEJOB_H
 #define UNDOSENDCREATEJOB_H
 
-#include <QObject>
 #include "kmail_private_export.h"
+#include <QObject>
 class KNotification;
 class QTimer;
 class KMAILTESTS_TESTS_EXPORT UndoSendCreateJob : public QObject
@@ -16,7 +16,7 @@ class KMAILTESTS_TESTS_EXPORT UndoSendCreateJob : public QObject
     Q_OBJECT
 public:
     explicit UndoSendCreateJob(QObject *parent = nullptr);
-    ~UndoSendCreateJob();
+    ~UndoSendCreateJob() override;
     Q_REQUIRED_RESULT bool canStart() const;
     Q_REQUIRED_RESULT bool start();
 
