@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,19 +7,20 @@
 #ifndef UNITYSERVICEMANAGER_H
 #define UNITYSERVICEMANAGER_H
 
+#include <AkonadiCore/Collection>
 #include <QModelIndex>
 #include <QObject>
-#include <AkonadiCore/Collection>
 class QDBusServiceWatcher;
 class QAbstractItemModel;
-namespace KMail {
+namespace KMail
+{
 class KMSystemTray;
 class UnityServiceManager : public QObject
 {
     Q_OBJECT
 public:
     explicit UnityServiceManager(QObject *parent = nullptr);
-    ~UnityServiceManager();
+    ~UnityServiceManager() override;
 
     void updateSystemTray();
     Q_REQUIRED_RESULT bool haveSystemTrayApplet() const;
@@ -30,6 +31,7 @@ public:
     Q_REQUIRED_RESULT bool excludeFolder(const Akonadi::Collection &collection) const;
     Q_REQUIRED_RESULT bool ignoreNewMailInFolder(const Akonadi::Collection &collection);
     void updateCount();
+
 private:
     Q_DISABLE_COPY(UnityServiceManager)
     void unreadMail(const QAbstractItemModel *model, const QModelIndex &parentIndex = {});
