@@ -1,20 +1,20 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kactionmenuaccount.h"
+#include "kmail_debug.h"
 #include <AkonadiCore/AgentInstance>
 #include <AkonadiCore/AgentManager>
 #include <MailCommon/MailUtil>
-#include "kmail_debug.h"
 #include <QMenu>
 
 KActionMenuAccount::KActionMenuAccount(QObject *parent)
     : KActionMenu(parent)
 {
-    setDelayed(true);
+    setPopupMode(QToolButton::DelayedPopup);
     connect(menu(), &QMenu::aboutToShow, this, &KActionMenuAccount::slotCheckTransportMenu);
     connect(menu(), &QMenu::triggered, this, &KActionMenuAccount::slotSelectAccount);
     connect(Akonadi::AgentManager::self(), &Akonadi::AgentManager::instanceNameChanged, this, &KActionMenuAccount::updateAccountMenu);
@@ -22,8 +22,7 @@ KActionMenuAccount::KActionMenuAccount(QObject *parent)
     connect(Akonadi::AgentManager::self(), &Akonadi::AgentManager::instanceAdded, this, &KActionMenuAccount::updateAccountMenu);
 }
 
-KActionMenuAccount::~KActionMenuAccount()
-= default;
+KActionMenuAccount::~KActionMenuAccount() = default;
 
 void KActionMenuAccount::setAccountOrder(const QStringList &identifier)
 {
